@@ -40,7 +40,11 @@ from moto.s3.exceptions import MissingBucket, MissingKey
 from moto.s3.models import FakeKey, s3_backends
 from moto.sqs.models import sqs_backends
 from moto.utilities.docker_utilities import DockerModel
-from moto.utilities.utils import load_resource_as_bytes
+from moto.utilities.utils import (
+    ARN_PARTITION_REGEX,
+    get_partition,
+    load_resource_as_bytes,
+)
 
 from .exceptions import (
     ConflictException,
@@ -280,12 +284,12 @@ def _s3_content(key: Any) -> Tuple[bytes, int, str, str]:
 
 
 def _validate_s3_bucket_and_key(
-    account_id: str, data: Dict[str, Any]
+    account_id: str, partition: str, data: Dict[str, Any]
 ) -> Optional[FakeKey]:
     key = None
     try:
         # FIXME: does not validate bucket region
-        key = s3_backends[account_id]["global"].get_object(
+        key = s3_backends[account_id][partition].get_object(
             data["S3Bucket"], data["S3Key"]
         )
     except MissingBucket:
@@ -440,7 +444,10 @@ class LayerVersion(CloudFormationModel):
                 self.code_digest,
             ) = _zipfile_content(self.content["ZipFile"])
         else:
-            key = _validate_s3_bucket_and_key(account_id, data=self.content)
+            partition = get_partition(region)
+            key = _validate_s3_bucket_and_key(
+                account_id, partition=partition, data=self.content
+            )
             if key:
                 (
                     self.code_bytes,
@@ -529,9 +536,7 @@ class LambdaAlias(BaseModel):
         description: str,
         routing_config: str,
     ):
-        self.arn = (
-            f"arn:aws:lambda:{region}:{account_id}:function:{function_name}:{name}"
-        )
+        self.arn = f"arn:{get_partition(region)}:lambda:{region}:{account_id}:function:{function_name}:{name}"
         self.name = name
         self.function_version = function_version
         self.description = description
@@ -607,6 +612,7 @@ class LambdaFunction(CloudFormationModel, DockerModel):
         # required
         self.account_id = account_id
         self.region = region
+        self.partition = get_partition(region)
         self.code = spec["Code"]
         self.function_name = spec["FunctionName"]
         self.handler = spec.get("Handler")
@@ -860,11 +866,13 @@ class LambdaFunction(CloudFormationModel, DockerModel):
             try:
                 if from_update:
                     # FIXME: does not validate bucket region
-                    key = s3_backends[self.account_id]["global"].get_object(
+                    key = s3_backends[self.account_id][self.partition].get_object(
                         updated_spec["S3Bucket"], updated_spec["S3Key"]
                     )
                 else:
-                    key = _validate_s3_bucket_and_key(self.account_id, data=self.code)
+                    key = _validate_s3_bucket_and_key(
+                        self.account_id, partition=self.partition, data=self.code
+                    )
             except MissingBucket:
                 if do_validate_s3():
                     raise ValueError(
@@ -1019,7 +1027,11 @@ class LambdaFunction(CloudFormationModel, DockerModel):
                         ]
                     )
                     for image_repo in image_repos:
-                        image_ref = f"{image_repo}:{self.run_time}"
+                        image_ref = (
+                            image_repo
+                            if ":" in image_repo
+                            else f"{image_repo}:{self.run_time}"
+                        )
                         try:
                             self.ensure_image_exists(image_ref)
                             break
@@ -1142,9 +1154,9 @@ class LambdaFunction(CloudFormationModel, DockerModel):
         spec = {
             "Code": properties["Code"],
             "FunctionName": resource_name,
-            "Handler": properties["Handler"],
+            "Handler": properties.get("Handler"),
             "Role": properties["Role"],
-            "Runtime": properties["Runtime"],
+            "Runtime": properties.get("Runtime"),
         }
 
         # NOTE: Not doing `properties.get(k, DEFAULT)` to avoid duplicating the
@@ -1422,6 +1434,7 @@ class LambdaStorage(object):
         )
         self.region_name = region_name
         self.account_id = account_id
+        self.partition = get_partition(region_name)
 
         # function-arn -> alias -> LambdaAlias
         self._aliases: Dict[str, Dict[str, LambdaAlias]] = defaultdict(lambda: {})
@@ -1451,7 +1464,7 @@ class LambdaStorage(object):
         if name in aliases:
             return aliases[name]
 
-        arn = f"arn:aws:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
+        arn = f"arn:{get_partition(self.region_name)}:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
         raise UnknownAliasException(arn)
 
     def put_alias(
@@ -1467,7 +1480,7 @@ class LambdaStorage(object):
         )
         aliases = self._get_function_aliases(function_name)
         if name in aliases:
-            arn = f"arn:aws:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
+            arn = f"arn:{get_partition(self.region_name)}:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
             raise ConflictException(f"Alias already exists: {arn}")
 
         alias = LambdaAlias(
@@ -1601,7 +1614,7 @@ class LambdaStorage(object):
         :raises: InvalidParameterValue if qualifier is provided
         """
 
-        if name_or_arn.startswith("arn:aws"):
+        if re.match(ARN_PARTITION_REGEX, name_or_arn):
             [_, name, qualifier] = self.split_function_arn(name_or_arn)
 
             if qualifier is not None:
@@ -1620,7 +1633,7 @@ class LambdaStorage(object):
         :raises: UnknownFunctionException if function not found
         """
 
-        if name_or_arn.startswith("arn:aws"):
+        if re.match(ARN_PARTITION_REGEX, name_or_arn):
             [_, name, qualifier_in_arn] = self.split_function_arn(name_or_arn)
             return self.get_function_by_name_with_qualifier(
                 name, qualifier_in_arn or qualifier
@@ -1631,7 +1644,7 @@ class LambdaStorage(object):
     def construct_unknown_function_exception(
         self, name_or_arn: str, qualifier: Optional[str] = None
     ) -> UnknownFunctionException:
-        if name_or_arn.startswith("arn:aws"):
+        if re.match(ARN_PARTITION_REGEX, name_or_arn):
             arn = name_or_arn
         else:
             # name_or_arn is a function name with optional qualifier <func_name>[:<qualifier>]
@@ -1648,7 +1661,7 @@ class LambdaStorage(object):
             if account != self.account_id:
                 raise CrossAccountNotAllowed()
             try:
-                iam_backend = iam_backends[self.account_id]["global"]
+                iam_backend = iam_backends[self.account_id][self.partition]
                 iam_backend.get_role_by_arn(fn.role)
             except IAMNotFoundException:
                 raise InvalidParameterValueException(
@@ -1691,7 +1704,7 @@ class LambdaStorage(object):
 
     def del_function(self, name_or_arn: str, qualifier: Optional[str] = None) -> None:
         # Qualifier may be explicitly passed or part of function name or ARN, extract it here
-        if name_or_arn.startswith("arn:aws"):
+        if re.match(ARN_PARTITION_REGEX, name_or_arn):
             # Extract from ARN
             if ":" in name_or_arn.split(":function:")[-1]:
                 qualifier = name_or_arn.split(":")[-1]
@@ -2273,7 +2286,7 @@ class LambdaBackend(BaseBackend):
             "Records": [
                 {
                     "eventID": item.to_json()["eventID"],
-                    "eventName": "INSERT",
+                    "eventName": item.to_json()["eventName"],
                     "eventVersion": item.to_json()["eventVersion"],
                     "eventSource": item.to_json()["eventSource"],
                     "awsRegion": self.region_name,
